@@ -1,9 +1,11 @@
 """ Holds graph utilities"""
 
 import os
-from typing import List, Tuple, Any, Dict, Set
 from pathlib import Path
+from typing import List, Tuple, Any, Dict, Set
 import networkx
+from terrawrap.exceptions import NoDependency
+from terrawrap.utils.config import walk_without_graph_directory
 
 
 def has_cycle(graph: networkx.DiGraph) -> bool:
@@ -17,10 +19,13 @@ def has_cycle(graph: networkx.DiGraph) -> bool:
         return True
 
     for source in sources:
-        cycle = networkx.find_cycle(graph, source)
-        if cycle:
-            print(cycle)
-            return True
+        try:
+            cycle = networkx.find_cycle(graph, source)
+            if cycle:
+                print(cycle)
+                return True
+        except networkx.NetworkXNoCycle:
+            return False
     return False
 
 
@@ -132,8 +137,17 @@ def connect_symlinks(graph: networkx.DiGraph, symlink_dict: Dict[str, Set[str]])
         current = symlink
         secondary = 0
         links = list(symlink_dict[symlink])
-        while secondary is not len(links):
+        while secondary != len(links):
             secondary_link = links[secondary]
-            graph.add_edge(current, secondary_link)
+
+            # TODO: implement better way for symlinked tf configs with terraform config
+            try:
+                links_to_run = walk_without_graph_directory(secondary_link)
+                for link in links_to_run:
+                    graph.add_edge(current, link)
+            except NoDependency as error:
+                print(error)
+                graph.add_edge(current, secondary_link)
+
             current = secondary_link
             secondary += 1
