@@ -2,6 +2,7 @@
 
 import os
 import platform
+import stat
 from typing import Dict, Tuple, Optional
 from urllib.parse import urlparse
 
@@ -28,7 +29,11 @@ class PluginDownload:
         """
         for name, path in plugin_paths.items():
             home = os.path.expanduser("~")
-            file_path = os.path.join(home, '.terraform.d/plugins', name)
+            plugin_directory = os.path.join(home, '.terraform.d/plugins')
+            os.makedirs(plugin_directory, exist_ok=True)
+
+            file_path = os.path.join(plugin_directory, name)
+
             system = platform.system()
             machine = platform.machine()
             path_with_platform = '%s/%s/%s' % (path, system, machine)
@@ -66,6 +71,9 @@ class PluginDownload:
             with(open(file_path, 'wb')) as out_file:
                 out_file.write(content)
 
+            mode = os.stat(file_path)
+            os.chmod(file_path, mode.st_mode | stat.S_IEXEC)
+
             if etag:
                 # AWS returns the etag surrounded by quotes
                 # remove them if that happens
@@ -110,8 +118,8 @@ class PluginDownload:
                 return None
 
             return response.content, response.headers.get('etag')
-        except requests.HTTPError:
-            raise FileDownloadFailed()
+        except requests.HTTPError as exception:
+            raise FileDownloadFailed() from exception
 
     def _get_s3_content(self, url: str, etag: Optional[str]) -> Optional[Tuple[bytes, Optional[str]]]:
         """Download a file from S3 using the AWS SDK"""
